OC.L10N.register(
    "mail",
    {
    "Mail" : "ایمیل",
    "Name" : "نوم",
    "Password" : "پاسورډ",
    "Save" : "ساتل",
    "Send" : "لېږل",
    "Unselect" : "سشیبشسیب",
    "Select" : "ټاکل",
    "Move" : "انتقال",
    "Delete" : "ړنګول",
    "Choose target folder" : "د ورانتقالېدو فولډر ټاکل",
    "No more subfolders in here" : "منځ فولډر نشته",
    "Choose" : "غوره کړئ",
    "Favorites" : "په نښه شوي",
    "Other" : "نور",
    "Settings" : "سمونې",
    "Cancel" : "پرېښول"
},
"nplurals=2; plural=(n != 1);");
